From ceae83bd25aadee094ec9d3a95cf27510cea2037 Mon Sep 17 00:00:00 2001
From: Justus Winter <justus@gnupg.org>
Date: Sun, 7 Aug 2016 15:16:57 +0200
Subject: proc: Fix references to the startup server.

* proc/main.c: Fix references to the startup server in code and
comments.
* proc/mgt.c: Likewise.
* proc/msg.c: Likewise.
* proc/proc.h: Likewise.
---
 proc/msg.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

(limited to 'proc/msg.c')

diff --git a/proc/msg.c b/proc/msg.c
index c7bab99e..1f132cd0 100644
--- a/proc/msg.c
+++ b/proc/msg.c
@@ -35,11 +35,11 @@ check_message_return (struct proc *p, void *availpaddr)
     }
 }
 
 /* Register ourselves with init. */
 static void *
-tickle_init (void *initport)
+tickle_statup (void *statupport)
 {
-  startup_essential_task ((mach_port_t) initport, mach_task_self (),
+  startup_essential_task ((mach_port_t) statupport, mach_task_self (),
 			  MACH_PORT_NULL, "proc", _hurd_host_priv);
   return NULL;
 }
@@ -65,11 +65,11 @@ S_proc_setmsgport (struct proc *p,
 
   if (p == startup_proc && startup_fallback)
     {
     /* Init is single threaded, so we can't delay our reply for
        the essential task RPC; spawn a thread to do it. */
       pthread_t thread;
       error_t err;
-      err = pthread_create (&thread, NULL, tickle_init,
+      err = pthread_create (&thread, NULL, tickle_statup,
 			    (void*) (uintptr_t) msgport);
       if (!err)
 	pthread_detach (thread);
@@ -35,11 +35,11 @@ check_message_return (struct proc *p, void *availpaddr)
 }
 
-/* Register ourselves with init. */
+/* Register ourselves with statup. */
 static void *
@@ -65,11 +65,11 @@ S_proc_setmsgport (struct proc *p,
   if (p == startup_proc && startup_fallback)
     {
-    /* Init is single threaded, so we can't delay our reply for
+    /* Statup is single threaded, so we can't delay our reply for
        the essential task RPC; spawn a thread to do it. */
       pthread_t thread;
-- 
cgit v1.2.3